# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These constants define how a time field is formatted before it is displayed.

The format may also depend on the system or document locale.

.. deprecated::

    Class is deprecated.

See Also:
    `API TimeDisplayFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html>`_
"""
STANDARD: Literal[0]
"""
the system standard
"""
HHMM: Literal[1]
"""
13:49
"""
HHMMSS: Literal[2]
"""
13:49:20
"""
HHMMSS00: Literal[3]
"""
13:49:20.30
"""
HHMMAMPM: Literal[4]
"""
01:49
"""
HHMMSSAMPM: Literal[5]
"""
01:49:20
"""
HHMMSS00AMPM: Literal[6]
"""
01:49:20.30
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XBridgeSupplier2(XInterface_8f010a43):
    """
    defines the interface for creating bridges to other object models.
    
    The created bridges are transparent to the user. That is, if one maps an interface into the target model, then the resulting target interface is a bridge implementation, that is not being noticed by an user. During a call on that interface, the bridge is invoked to convert the arguments and carry out a call according to the rules of the source model. Return values are automatically mapped to the types of the target model.
    
    Simple types are mapped to simple target types. That is, there is no additional bridging code involved when those types are being used.
    
    Sometimes a bridge cannot be created, depending on whether a program uses the XBridgeSupplier2 interface remotely. Assuming one wants to bridge an OLE Automation object to UNO by calling createBridge on a proxy, then the UNO remote bridge would not recognise that the Any argument contains an IDispatch interface. Therefore it cannot marshal it as COM requires it and the bridgeing would fail. To prevent this, implementations of this interface should be aware of this scenario and if necessary take the appropriate steps. The process ID argument to the createBridge function represents the calling process and may be used by the implementation to determine if it is being accessed remotely.
    
    All objects, whether they are part of the UNO object model or not, are carried in an any. The representation of this object is heavily model-dependent and has to be specified in the following list:
    
    Any implementation can supply its own bridges to other object models by implementing this interface and returning the bridge when the method XBridgeSupplier2.createBridge() is called with itself as the first parameter.

    See Also:
        `API XBridgeSupplier2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1bridge_1_1XBridgeSupplier2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.bridge.XBridgeSupplier2']

    def createBridge(self, aModelDepObject: object, aProcessId: 'typing.Tuple[int, ...]', nSourceModelType: int, nDestModelType: int) -> object:
        """
        creates a bridge to provide an object of one object model with another.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...beans.string_pair import StringPair as StringPair_a4bc0b14
    from .x_fast_document_handler import XFastDocumentHandler as XFastDocumentHandler_454c0fb6
    from .x_fast_token_handler import XFastTokenHandler as XFastTokenHandler_17510e78

class XFastSAXSerializable(ABC):
    """
    serializes a DOM tree by generating FastSAX events.
    
    **since**
    
        OOo 3.1

    See Also:
        `API XFastSAXSerializable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastSAXSerializable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XFastSAXSerializable']

    def fastSerialize(self, handler: 'XFastDocumentHandler_454c0fb6', tokenHandler: 'XFastTokenHandler_17510e78', namespaces: 'typing.Tuple[StringPair_a4bc0b14, ...]', registerNamespaces: 'typing.Tuple[typing.Tuple[str, int], ...]') -> None:
        """
        serializes an object (e.g.
        
        a DOM tree) that represents an XML document by generating fast SAX events.
        
        This is necessary mostly because the DOM implementation does not permit attaching namespaces declarations directly to nodes, which may lead to duplicate namespace declarations on export, and thus larger documents. Note that the first part of each tuple is the prefix, e.g. \"office\", and the second is the numeric namespace identifier.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from typing_extensions import Literal


class EffectCommands(object):
    """
    Const


    See Also:
        `API EffectCommands <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation_1_1EffectCommands.html>`_
    """
    CUSTOM: Literal[0]
    """
    the command is user defined
    """
    VERB: Literal[1]
    """
    the command is an OLE verb.
    
    Required parameters are \"Verb\" of type long that specifies the verb to execute.
    """
    PLAY: Literal[2]
    """
    the command starts playing on a media object.
    
    Optional parameters are \"MediaTime\" of type double that specifies the start time in milliseconds. If not given, play continues at last position known.
    """
    TOGGLEPAUSE: Literal[3]
    """
    the command toggles the pause status on a media object.
    """
    STOP: Literal[4]
    """
    the command stops the animation on a media object
    """
    STOPAUDIO: Literal[5]
    """
    the command stops all currently running sound effects.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .sub_increment import SubIncrement as SubIncrement_c5630c1b


class IncrementData(object):
    """
    Struct Class

    An IncrementData describes how tickmarks are positioned on the scale of an axis.

    See Also:
        `API IncrementData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1IncrementData.html>`_
    """
    typeName: Literal['com.sun.star.chart2.IncrementData']

    def __init__(self, SubIncrements: typing.Optional[typing.Tuple[SubIncrement_c5630c1b, ...]] = ..., Distance: typing.Optional[object] = ..., PostEquidistant: typing.Optional[object] = ..., BaseValue: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            SubIncrements (typing.Tuple[SubIncrement, ...], optional): SubIncrements value.
            Distance (object, optional): Distance value.
            PostEquidistant (object, optional): PostEquidistant value.
            BaseValue (object, optional): BaseValue value.
        """


    @property
    def SubIncrements(self) -> typing.Tuple[SubIncrement_c5630c1b, ...]:
        """
        SubIncrements describes the positioning of further sub tickmarks on the scale of an axis.
        
        The first SubIncrement in this sequence determines how the distance between two neighboring main tickmarks is divided for positioning of further sub tickmarks. Every following SubIncrement determines the positions of subsequent tickmarks in relation to their parent tickmarks given by the preceding SubIncrement.
        """


    @property
    def Distance(self) -> object:
        """
        if the any contains a double value this is used as a fixed Distance value.
        
        Otherwise, if the any is empty or contains an incompatible type, the Distance is meant to be calculated automatically by the view component representing the model containing this increment.
        """


    @property
    def PostEquidistant(self) -> object:
        """
        PostEquidistant rules whether the member Distance describes a distance before or after the scaling is applied.
        
        If PostEquidistant equals TRUE Distance is given in values after XScaling is applied, thus resulting main tickmarks will always look equidistant on the screen. If PostEquidistant equals FALSE Distance is given in values before XScaling is applied.
        """


    @property
    def BaseValue(self) -> object:
        """
        if the any contains a double value this is used as a fixed BaseValue.
        
        Otherwise, if the any is empty or contains an incompatible type, the BaseValue is meant to be calculated automatically by the view component representing the model containing this increment.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class FieldUnit(object):
    """
    Const

    specifies attributes for the MetricField map units.
    
    IMPORTANT: These constants have to be disjunct with constants in util/MeasureUnit.

    See Also:
        `API FieldUnit <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html>`_
    """
    FUNIT_NONE: Literal[0]
    FUNIT_MM: Literal[1]
    FUNIT_CM: Literal[2]
    FUNIT_M: Literal[3]
    FUNIT_KM: Literal[4]
    FUNIT_TWIP: Literal[5]
    FUNIT_POINT: Literal[6]
    FUNIT_PICA: Literal[7]
    FUNIT_INCH: Literal[8]
    FUNIT_FOOT: Literal[9]
    FUNIT_MILE: Literal[10]
    FUNIT_CUSTOM: Literal[11]
    FUNIT_PERCENT: Literal[12]
    FUNIT_100TH_MM: Literal[13]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.string_pair import StringPair as StringPair_a4bc0b14

class XRelationshipAccess(XInterface_8f010a43):
    """
    This interface allows to get access to relationship data.
    
    The relationship data is organized as a set of entries. Each of entry is represented by a set of tags, where each tag has unique for this entry name and a string value. An entry must contain at least one tag named \"ID\", the value of this tag must be unique for the whole set of entries, this tag is used as a unique identifier of an entry.

    See Also:
        `API XRelationshipAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XRelationshipAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XRelationshipAccess']

    def clearRelationships(self) -> None:
        """
        allows to clear the set of entries.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def getAllRelationships(self) -> 'typing.Tuple[typing.Tuple[StringPair_a4bc0b14, ...], ...]':
        """
        retrieves the sequence containing all the entries controlled by the object.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def getRelationshipByID(self, sID: str) -> 'typing.Tuple[StringPair_a4bc0b14, ...]':
        """
        retrieves the sequence containing all the tags from the entry with specified value of \"ID\" tag.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
        """
    def getRelationshipsByType(self, sType: str) -> 'typing.Tuple[typing.Tuple[StringPair_a4bc0b14, ...], ...]':
        """
        retrieves the sequence containing all the entries which \"Type\" tag takes the specified value.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def getTargetByID(self, sID: str) -> str:
        """
        retrieves the value of \"Target\" tag from the entry with specified \"ID\" tag.
        
        If the entry has no \"Target\" tag an empty string is returned.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
        """
    def getTypeByID(self, sID: str) -> str:
        """
        retrieves the value of \"Type\" tag from the entry with specified \"ID\" tag.
        
        If the entry has no \"Type\" tag an empty string is returned.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
        """
    def hasByID(self, sID: str) -> bool:
        """
        allows to detect whether there is an entry with specified value of \"ID\" tag.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def insertRelationshipByID(self, sID: str, aEntry: 'typing.Tuple[StringPair_a4bc0b14, ...]', bReplace: bool) -> None:
        """
        allows to insert an entry.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
        """
    def insertRelationships(self, aEntries: 'typing.Tuple[typing.Tuple[StringPair_a4bc0b14, ...], ...]', bReplace: bool) -> None:
        """
        allows to insert a set of entries

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
        """
    def removeRelationshipByID(self, sID: str) -> None:
        """
        allows to remove an entry.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
"""
Const

flags used for the event type in dictionary events.

These flags represent the type of events that a dictionary may broadcast.

See Also:
    `API DictionaryEventFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryEventFlags.html>`_
"""
ADD_ENTRY: Literal[1]
"""
indicates that at least one entry has been added.
"""
DEL_ENTRY: Literal[2]
"""
indicates that at least one entry has been deleted.
"""
CHG_NAME: Literal[4]
"""
the dictionary's name has changed.
"""
CHG_LANGUAGE: Literal[8]
"""
the dictionary's language has changed.
"""
ENTRIES_CLEARED: Literal[16]
"""
all entries have been removed.
"""
ACTIVATE_DIC: Literal[32]
"""
used when the dictionary was activated.
"""
DEACTIVATE_DIC: Literal[64]
"""
used when the dictionary was deactivated.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from .x_proofreader import XProofreader as XProofreader_dab0e46

class Proofreader(XProofreader_dab0e46):
    """
    Service Class

    provides a proofreader (often known as grammar checker) for text
    
    An implementation of this service will receive text and has to identify the sentence end and report all errors found.
    
    An implementation of this service is not limited to grammar checking at all. It might also check style, used terms etc. Basically it can check every aspect of a single sentence. Since the text provided is always the complete paragraph it can also choose to analyze the context of the sentence currently required to be checked. However error reports need to be limited to the current sentence.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API Proofreader <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1linguistic2_1_1Proofreader.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from .simple_set_access import SimpleSetAccess as SimpleSetAccess_5ea81068
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d

class SimpleSetUpdate(SimpleSetAccess_5ea81068, XNameContainer_cb90e47, XMultiServiceFactory_191e0eb6, XSingleServiceFactory_27210f0d):
    """
    Service Class

    provides write access to a dynamic, homogeneous, non-hierarchical set of values or objects.
    
    Allows adding and removing elements. Helps create new elements to be added.
    
    This service extends SimpleSetAccess to support modifying the container. Any child objects shall in turn support modifying access.

    See Also:
        `API SimpleSetUpdate <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetUpdate.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xforms
from typing_extensions import Literal
import typing
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from ..xsd.x_data_type import XDataType as XDataType_83f209cb

class XDataTypeRepository(XEnumerationAccess_4bac0ffc, XNameAccess_e2ab0cf6):
    """
    specifies a repository of XSD data types
    
    The elements of the repository are instances supporting the com.sun.star.xsd.XDataType interface.

    See Also:
        `API XDataTypeRepository <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xforms_1_1XDataTypeRepository.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xforms.XDataTypeRepository']

    def cloneDataType(self, sourceName: str, newName: str) -> 'XDataType_83f209cb':
        """
        creates a clone of the given data type, and inserts it into the repository

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    def getBasicDataType(self, dataTypeClass: int) -> 'XDataType_83f209cb':
        """
        retrieves the basic type for the given type class

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def getDataType(self, typeName: str) -> 'XDataType_83f209cb':
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def revokeDataType(self, typeName: str) -> None:
        """
        removes a data type given by name from the repository

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.util.VetoException: ``VetoException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing.framework
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_resource_id import XResourceId as XResourceId_5be3103d

class XResource(ABC):
    """
    Base interface that provides functionality shared by all resource types of the drawing framework.

    See Also:
        `API XResource <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XResource.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.framework.XResource']

    def getResourceId(self) -> 'XResourceId_5be3103d':
        """
        Return an XResourceId object for the called resource.
        
        The returned id unambiguously identifies the resource.
        """
    def isAnchorOnly(self) -> bool:
        """
        Some resources must not be leafs, i.e.
        
        have to be anchor to at least one other resource. Most panes are examples for this. Views on the other hand are in most cases no anchors. So the typical pane will return TRUE and the typical view will return FALSE.
        
        The return value is used to determine whether a resource has to be deactivated when it has no children, either because none is requested or because none can be created.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XBridge(XInterface_8f010a43):
    """
    main interface for an interprocess bridge.

    See Also:
        `API XBridge <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1bridge_1_1XBridge.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.bridge.XBridge']

    def getDescription(self) -> str:
        """
        a unique descriptive string: protocol + \":\" + XConnection.getDescription()
        """
    def getInstance(self, sInstanceName: str) -> 'XInterface_8f010a43':
        """
        tries to get an interface from the remote that is known by this name.
        
        In general, this method is called once to get the initial object from the remote, but it is allowed to call the method multiple times.
        """
    def getName(self) -> str:
        """
        name that the bridge got when it was created.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from ..lang.x_localizable import XLocalizable as XLocalizable_aee00b64

class XAddIn(XLocalizable_aee00b64):
    """
    gives access to function descriptions and user-visible names.

    See Also:
        `API XAddIn <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XAddIn.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XAddIn']

    def getArgumentDescription(self, aProgrammaticFunctionName: str, nArgument: int) -> str:
        """
        returns the description of the specified argument.
        
        The argument description is shown to the user when prompting for arguments. It may be translated to the current language of the AddIn.
        """
    def getDisplayArgumentName(self, aProgrammaticFunctionName: str, nArgument: int) -> str:
        """
        returns the user-visible name of the specified argument.
        
        The argument name is shown to the user when prompting for arguments. It should be a single word and may be translated to the current language of the AddIn.
        """
    def getDisplayCategoryName(self, aProgrammaticFunctionName: str) -> str:
        """
        returns the user-visible name of the category the function belongs to.
        
        This is used when category names are shown to the user.
        """
    def getDisplayFunctionName(self, aProgrammaticName: str) -> str:
        """
        returns the user-visible function name for an internal name.
        
        The user-visible name of a function is the name shown to the user. It may be translated to the current language of the AddIn, so it is never stored in files. It should be a single word and is used when entering or displaying formulas.
        """
    def getFunctionDescription(self, aProgrammaticName: str) -> str:
        """
        returns the description of a function.
        
        The description is shown to the user when selecting functions. It may be translated to the current language of the AddIn.
        """
    def getProgrammaticCategoryName(self, aProgrammaticFunctionName: str) -> str:
        """
        returns the programmatic name of the category the function belongs to.
        
        The category name is used to group similar functions together. The programmatic category name should always be in English, it is never shown to the user. It should be one of the following names if the function falls into the corresponding category.
        """
    def getProgrammaticFuntionName(self, aDisplayName: str) -> str:
        """
        returns the internal function name for an user-visible name.
        
        The user-visible name of a function is the name shown to the user. It may be translated to the current language of the AddIn, so it is never stored in files. It should be a single word and is used when entering or displaying formulas.
        
        Attention: The method name contains a spelling error. Due to compatibility reasons the name cannot be changed.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.validation
from typing_extensions import Literal
import typing
from .x_validatable import XValidatable as XValidatable_49570fc6
if typing.TYPE_CHECKING:
    from .x_form_component_validity_listener import XFormComponentValidityListener as XFormComponentValidityListener_ac141740

class XValidatableFormComponent(XValidatable_49570fc6):
    """
    is a convenience interface for accessing several aspects of a form component which supports validation.
    
    A validatable form component has two aspects which other parties might be interested in:
    
    An XValidatableFormComponent allows to easily access both of these aspects.
    
    Note that all of the information provided at this interface can also obtained by other means, but much more inconveniently.

    See Also:
        `API XValidatableFormComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1validation_1_1XValidatableFormComponent.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.validation.XValidatableFormComponent']

    def addFormComponentValidityListener(self, Listener: 'XFormComponentValidityListener_ac141740') -> None:
        """
        registers the given listener.
        
        XFormComponentValidityListeners are called whenever any of the aspects of the validatable form component (the validity flag, or the value) changed.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """
    def getCurrentValue(self) -> object:
        """
        retrieves the current value of the component.
        
        The type of the current value, as well as it's semantics, depend on the service implementing this interface.
        
        Again, this is a convenience method. For example, for a com.sun.star.form.component.FormattedField, calling this method is equivalent to retrieving the com.sun.star.awt.UnoControlFormattedFieldModel.EffectiveValue.
        
        If no validator has been set (XValidatable.setValidator()), the value returned here is defined by the service implementing this interface.
        """
    def isValid(self) -> bool:
        """
        determines whether the current value of the component passed the validity test at the validator.
        
        Calling this is equal to calling XValidator.isValid() with the current value (see getCurrentValue()) of the component, where the validator is obtained via XValidatable.getValidator().
        
        If no validator has been set (XValidatable.setValidator()), this method returns true.
        """
    def removeFormComponentValidityListener(self, Listener: 'XFormComponentValidityListener_ac141740') -> None:
        """
        registers the given listener.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2

class XStringListControl(XPropertyControl_3f260fe2):
    """
    defines the interface for an XPropertyControl which, additionally to the basic behavior, supports a list of strings interpreted as possible property values.
    
    A control which would canonically implement this interface is a list box control: The string list defined by XStringListControl would in the control be represented as drop-down list containing all the strings.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XStringListControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XStringListControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XStringListControl']

    def appendListEntry(self, NewEntry: str) -> None:
        """
        appends a new entry to the end of the list
        """
    def clearList(self) -> None:
        """
        clears the whole list
        """
    def getListEntries(self) -> 'typing.Tuple[str, ...]':
        """
        gets all list entries
        """
    def prependListEntry(self, NewEntry: str) -> None:
        """
        prepends a new entry to the beginning of the list
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.control
from ...awt.uno_control_formatted_field import UnoControlFormattedField as UnoControlFormattedField_4a610ff1
from ..x_bound_control import XBoundControl as XBoundControl_bba00bed

class FormattedField(UnoControlFormattedField_4a610ff1, XBoundControl_bba00bed):
    """
    Service Class

    describes a control which can be used for inputting values with an arbitrary formatting, and can (but not necessarily has to) be bound to a database field.
    
    The model of the control has to support the com.sun.star.form.component.FormattedField service.
    
    In addition, this control can be used in HTML forms. It triggers the com.sun.star.form.XSubmit.submit() method of the form it belongs to if the enter key is pressed while it has the focus.

    See Also:
        `API FormattedField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1FormattedField.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from typing_extensions import Literal


class EffectPresetClass(object):
    """
    Const

    This constants defines the class for a preset animation effect.
    
    This is stored with the name preset-class inside the com.sun.star.animations.XAnimationNode.UserData sequence.
    This does not manipulate the timing or synchronization. It can be used to quickly identify preset animations inside an animation hierarchy.

    See Also:
        `API EffectPresetClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation_1_1EffectPresetClass.html>`_
    """
    CUSTOM: Literal[0]
    ENTRANCE: Literal[1]
    EXIT: Literal[2]
    EMPHASIS: Literal[3]
    MOTIONPATH: Literal[4]
    OLEACTION: Literal[5]
    MEDIACALL: Literal[6]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_key_handler import XKeyHandler as XKeyHandler_98520a93
    from .x_mouse_click_handler import XMouseClickHandler as XMouseClickHandler_edcb0d59

class XUserInputInterception(XInterface_8f010a43):
    """
    Interface to add handlers for key and mouse events.
    
    A handler is not a passive listener, it can even consume the event.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XUserInputInterception <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XUserInputInterception']

    def addKeyHandler(self, xHandler: 'XKeyHandler_98520a93') -> None:
        """
        Add a new listener that is called on com.sun.star.awt.KeyEvent.
        
        Every listener is given the opportunity to consume the event, i.e. prevent the not yet called listeners from being called.
        """
    def addMouseClickHandler(self, xHandler: 'XMouseClickHandler_edcb0d59') -> None:
        """
        Add a new listener that is called on com.sun.star.awt.MouseEvent.
        
        Every listener is given the opportunity to consume the event, i.e. prevent the not yet called listeners from being called.
        """
    def removeKeyHandler(self, xHandler: 'XKeyHandler_98520a93') -> None:
        """
        Remove the specified listener from the list of listeners.
        """
    def removeMouseClickHandler(self, xHandler: 'XMouseClickHandler_edcb0d59') -> None:
        """
        Remove the specified listener from the list of listeners.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class ImagePosition(object):
    """
    Const

    specifies the position of an image, relative to another object

    See Also:
        `API ImagePosition <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1ImagePosition.html>`_
    """
    LeftTop: Literal[0]
    """
    specifies that the image should be positioned at the left of, and top-aligned to, the other object
    """
    LeftCenter: Literal[1]
    """
    specifies that the image should be positioned at the left of, and vertically centered to, the other object
    """
    LeftBottom: Literal[2]
    """
    specifies that the image should be positioned at the left of, and bottom-aligned to, the other object
    """
    RightTop: Literal[3]
    """
    specifies that the image should be positioned at the right of, and top-aligned to, the other object
    """
    RightCenter: Literal[4]
    """
    specifies that the image should be positioned at the right of, and vertically centered to, the other object
    """
    RightBottom: Literal[5]
    """
    specifies that the image should be positioned at the right of, and bottom-aligned to, the other object
    """
    AboveLeft: Literal[6]
    """
    specifies that the image should be positioned above and left-aligned to the other object
    """
    AboveCenter: Literal[7]
    """
    specifies that the image should be positioned above and horizontally centered to the other object
    """
    AboveRight: Literal[8]
    """
    specifies that the image should be positioned above and right-aligned to the other object
    """
    BelowLeft: Literal[9]
    """
    specifies that the image should be positioned below and left-aligned to the other object
    """
    BelowCenter: Literal[10]
    """
    specifies that the image should be positioned below and horizontally centered to the other object
    """
    BelowRight: Literal[11]
    """
    specifies that the image should be positioned below and right-aligned centered to the other object
    """
    Centered: Literal[12]
    """
    specifies that the image should be horizontally and vertically centered to the other object.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_office_database_document import XOfficeDatabaseDocument as XOfficeDatabaseDocument_327f0f39

class XDocumentDataSource(ABC):
    """
    simplifies the accessing of data sources and their corresponding database document.
    
    The interface can be used to access the data source of the database document.

    See Also:
        `API XDocumentDataSource <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDocumentDataSource.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XDocumentDataSource']

    @property
    def DatabaseDocument(self) -> 'XOfficeDatabaseDocument_327f0f39':
        """
        provides access to the one and only OfficeDatabaseDocument which the data source is based on.
        
        The component returned by this attribute is an OfficeDatabaseDocument.
        
        Though there is a 1-to-1 relationship between database documents and data sources, each of the two can exist without its counterpart, but create this counterpart on request only. As a consequence, the document obtained via this attribute might be newly created, which implies that the caller is now responsible for it. In particular, the caller is responsible for calling com.sun.star.util.XCloseable.close() on the document as soon as it's not needed anymore.
        
        Additionally, if the caller does long-lasting processing on the document, it's advised to add itself as com.sun.star.util.XCloseListener to the document, to prevent closing as long as the processing lasts.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.resource
from typing_extensions import Literal
import typing
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XStringResourceResolver(XModifyBroadcaster_fd990df0):
    """
    Interface to access strings in a resource.
    
    The interface is derived from com.sun.star.util.XModifyBroadcaster
    
    All registered com.sun.star.util.XModifyListener interfaces will be notified if either the current locale changes or if a string is added, changed or removed. This usually will only happen if the implementing object also supports the interface com.sun.star.resource.XStringResourceManager and is used in the design mode of a Dialog or String table editor. But also changing the locale at runtime can be supported in this way.

    See Also:
        `API XStringResourceResolver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourceResolver.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.resource.XStringResourceResolver']

    def getCurrentLocale(self) -> 'Locale_70d308fa':
        """
        Returns the current locale specified in the accessed resource.
        
        If no locale is available, the returned Locale structure only contains empty strings.
        """
    def getDefaultLocale(self) -> 'Locale_70d308fa':
        """
        Returns the default locale of the accessed resource.
        
        In many cases this will be the locale of the Office initially used to create the resource.
        """
    def getLocales(self) -> 'typing.Tuple[Locale_70d308fa, ...]':
        """
        Returns a sequence of all supported locales.
        """
    def getResourceIDs(self) -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence of all valid Resource IDs for the current locale.
        """
    def getResourceIDsForLocale(self, locale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence of all valid Resource IDs for a specific locale.
        
        It's not recommended to use this method to get the best performance as the implementation may be optimized for the use of the current locale.
        """
    def hasEntryForId(self, ResourceID: str) -> bool:
        """
        Checks if the resource contains an entry for the given ResourceID and current locale.
        """
    def hasEntryForIdAndLocale(self, ResourceID: str, locale: 'Locale_70d308fa') -> bool:
        """
        Checks if the resource contains an entry for the given ResourceID and locale.
        
        It's not recommended to use this method to get the best performance as the implementation may be optimized for the use of the current locale.
        """
    def resolveString(self, ResourceID: str) -> str:
        """
        Resolves the passed ResourceID for the current locale.
        
        This locale is set during initialization of the object implementing this interface or - in case that also the interface com.sun.star.resource.XStringResourceManager is supported - by using the XStringResourceManager.setLocale method.

        Raises:
            com.sun.star.resource.MissingResourceException: ``MissingResourceException``
        """
    def resolveStringForLocale(self, ResourceID: str, locale: 'Locale_70d308fa') -> str:
        """
        Resolves the passed ResourceID for a specific locale.
        
        It's not recommended to use this method to get the best performance as the implementation may be optimized for the use of the current locale.

        Raises:
            com.sun.star.resource.MissingResourceException: ``MissingResourceException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class ProtocolHandler(XDispatchProvider_fc690de6, XInitialization_d46c0cca):
    """
    Service Class

    special dispatch provider registered for URL protocols
    
    The generic dispatch mechanism on a Frame search for such registered protocol handler and use it if it agrees with the dispatched URL.
    
    Supported URLs must match follow format: protocol scheme:protocol specific part If a handler provides optional arguments (\"?\") or jump marks (\"#\") depends from his definition and implementation. The generic dispatch provider will use registered URL pattern to detect right handler.

    See Also:
        `API ProtocolHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1ProtocolHandler.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .number_format_code import NumberFormatCode as NumberFormatCode_d9a00c95
    from ..lang.locale import Locale as Locale_70d308fa

class XNumberFormatCode(XInterface_8f010a43):
    """
    Access number format codes defined in locale data.

    See Also:
        `API XNumberFormatCode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XNumberFormatCode.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XNumberFormatCode']

    def getAllFormatCode(self, nFormatUsage: int, rLocale: 'Locale_70d308fa') -> 'typing.Tuple[NumberFormatCode_d9a00c95, ...]':
        """
        returns all format codes for a given nFormatUsage and locale.
        """
    def getAllFormatCodes(self, rLocale: 'Locale_70d308fa') -> 'typing.Tuple[NumberFormatCode_d9a00c95, ...]':
        """
        returns all format codes for a given locale.
        """
    def getDefault(self, nFormatType: int, nFormatUsage: int, rLocale: 'Locale_70d308fa') -> 'NumberFormatCode_d9a00c95':
        """
        returns the default number format code of a specific category (usage group) for a given locale and format length type.
        """
    def getFormatCode(self, nFormatIndex: int, rLocale: 'Locale_70d308fa') -> 'NumberFormatCode_d9a00c95':
        """
        returns the number format pointed to by nFormatIndex for a given locale.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from .x_array import XArray as XArray_708108fb
    from .x_blob import XBlob as XBlob_6773087b
    from .x_clob import XClob as XClob_6777087c
    from .x_ref import XRef as XRef_5f110819
    from ..util.date import Date as Date_60040844
    from ..util.date_time import DateTime as DateTime_84de09d3
    from ..util.time import Time as Time_604e0855

class XParameters(XInterface_8f010a43):
    """
    is used for parameter setting, commonly implemented in conjunction with PreparedStatements.
    
    Note: The setXXX methods for setting IN parameter values must specify types that are compatible with the defined SQL type of the input parameter. For instance, if the IN parameter has SQL type Integer, then the method com.sun.star.sdbc.XParameters.setInt() should be used.
    
    If arbitrary parameter type conversions are required, the method com.sun.star.sdbc.XParameters.setObject() should be used with a target SQL type.
    
    Example of setting a parameter; con is an active connection.

    See Also:
        `API XParameters <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XParameters.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XParameters']

    def clearParameters(self) -> None:
        """
        clears the current parameter values immediately.
        
        In general, parameter values remain in force for repeated use of a Statement. Setting a parameter value automatically clears its previous value. However, in some cases it is useful to immediately release the resources used by the current parameter values; this can be done by calling clearParameters.

        Raises:
            SQLException: ``SQLException``
        """
    def setArray(self, parameterIndex: int, x: 'XArray_708108fb') -> None:
        """
        sets an Array parameter.

        Raises:
            SQLException: ``SQLException``
        """
    def setBinaryStream(self, parameterIndex: int, x: 'XInputStream_98d40ab4', length: int) -> None:
        """
        sets the designated parameter to the given input stream, which will have the specified number of bytes.
        
        When a very large binary value is input to a LONGVARBINARY or LONGVARCHAR parameter, it may be more practical to send it via an com.sun.star.io.XInputStream . SDBC will read the data from the stream as needed, until it reaches end-of-file.

        Raises:
            SQLException: ``SQLException``
        """
    def setBlob(self, parameterIndex: int, x: 'XBlob_6773087b') -> None:
        """
        sets a BLOB parameter.

        Raises:
            SQLException: ``SQLException``
        """
    def setBoolean(self, parameterIndex: int, x: bool) -> None:
        """
        sets the designated parameter to a boolean value.
        
        The driver converts this to a SQL BIT value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setByte(self, parameterIndex: int, x: int) -> None:
        """
        sets the designated parameter to a byte value.
        
        The driver converts this to a SQL TINYINT value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setBytes(self, parameterIndex: int, x: 'typing.Tuple[int, ...]') -> None:
        """
        sets the designated parameter to a sequence of bytes.
        
        The driver converts this to a SQL VARBINARY or LONGVARBINARY (depending on the argument's size relative to the driver's limits on VARBINARYs) when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setCharacterStream(self, parameterIndex: int, x: 'XInputStream_98d40ab4', length: int) -> None:
        """
        sets the designated parameter to the given input stream, which will have the specified number of bytes.
        
        When a very large binary value is input to a LONGVARCHAR parameter, it may be more practical to send it via a com.sun.star.io.XInputStream . SDBC will read the data from the stream as needed, until it reaches end-of-file.

        Raises:
            SQLException: ``SQLException``
        """
    def setClob(self, parameterIndex: int, x: 'XClob_6777087c') -> None:
        """
        sets a CLOB parameter.

        Raises:
            SQLException: ``SQLException``
        """
    def setDate(self, parameterIndex: int, x: 'Date_60040844') -> None:
        """
        sets the designated parameter to a date value.
        
        The driver converts this to a SQL DATE value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setDouble(self, parameterIndex: int, x: float) -> None:
        """
        sets the designated parameter to a double value.
        
        The driver converts this to a SQL DOUBLE value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setFloat(self, parameterIndex: int, x: float) -> None:
        """
        sets the designated parameter to a float value.
        
        The driver converts this to a SQL FLOAT value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setInt(self, parameterIndex: int, x: int) -> None:
        """
        sets the designated parameter to a long value.
        
        The driver converts this to a SQL INTEGER value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setLong(self, parameterIndex: int, x: int) -> None:
        """
        sets the designated parameter to a hyper value.
        
        The driver converts this to a SQL BIGINT value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setNull(self, parameterIndex: int, sqlType: int) -> None:
        """
        sets the designated parameter to SQL NULL.

        Raises:
            SQLException: ``SQLException``
        """
    def setObject(self, parameterIndex: int, x: object) -> None:
        """
        sets the value of a parameter using an any.
        
        The given object will be converted to the targetSqlType before being sent to the database. If the object has a custom mapping (is of a class implementing SQLData), the SDBC driver should call its method writeSQL to write it to the SQL data stream. If, on the other hand, the object is of a service implementing Ref, Blob, Clob, Struct, or Array, the driver should pass it to the database as a value of the corresponding SQL type.
        
        Note that this method may be used to pass database-specific abstract data types.

        Raises:
            SQLException: ``SQLException``
        """
    def setObjectNull(self, parameterIndex: int, sqlType: int, typeName: str) -> None:
        """
        sets the designated parameter to SQL NULL.
        
        This version of setNull should be used for user-named types and REF type parameters. Examples of user-named types include: STRUCT, DISTINCT, OBJECT, and named array types.
        
        Note: To be portable, applications must give the SQL type code and the fully-qualified SQL type name when specifying a NULL user-defined or REF parameter. In the case of a user-named type the name is the type name of the parameter itself. For a REF parameter the name is the type name of the referenced type. If a SDBC driver does not need the type code or type name information, it may ignore it.
        Although it is intended for user-named and Ref parameters, this method may be used to set a null parameter of any JDBC type. If the parameter does not have a user-named or REF type, the given typeName is ignored.

        Raises:
            SQLException: ``SQLException``
        """
    def setObjectWithInfo(self, parameterIndex: int, x: object, targetSqlType: int, scale: int) -> None:
        """
        set a value from the Datatype ANY for a parameter.
        
        The given object will be converted to the targetSqlType before being sent to the database. If the object has a custom mapping (is of a class implementing SQLData), the SDBC driver should call its method writeSQL to write it to the SQL data stream. If, on the other hand, the object is of a service implementing Ref, Blob, Clob, Struct, or Array, the driver should pass it to the database as a value of the corresponding SQL type.
        
        Note that this method may be used to pass database-specific abstract data types.

        Raises:
            SQLException: ``SQLException``
        """
    def setRef(self, parameterIndex: int, x: 'XRef_5f110819') -> None:
        """
        sets a REF(&lt;structured-type&gt;) parameter.

        Raises:
            SQLException: ``SQLException``
        """
    def setShort(self, parameterIndex: int, x: int) -> None:
        """
        sets the designated parameter to a short value.
        
        The driver converts this to a SQL SMALLINT value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setString(self, parameterIndex: int, x: str) -> None:
        """
        sets the designated parameter to a string value.
        
        The driver converts this to a SQL VARCHAR or LONGVARCHAR value (depending on the argument's size relative to the driver's limits on VARCHARs) when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setTime(self, parameterIndex: int, x: 'Time_604e0855') -> None:
        """
        sets the designated parameter to a time value.
        
        The driver converts this to a SQL TIME value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """
    def setTimestamp(self, parameterIndex: int, x: 'DateTime_84de09d3') -> None:
        """
        sets the designated parameter to a datetime value.
        
        The driver converts this to a SQL TIMESTAMP value when it sends it to the database.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .rectangle import Rectangle as Rectangle_84b109e9
    from .window_descriptor import WindowDescriptor as WindowDescriptor_d61e0ceb
    from .x_device import XDevice as XDevice_70ba08fc
    from .x_region import XRegion as XRegion_70f30910
    from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0

class XToolkit(XInterface_8f010a43):
    """
    specifies a factory interface for the window toolkit.
    
    This is similar to the abstract window toolkit (AWT) in Java.

    See Also:
        `API XToolkit <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkit.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XToolkit']

    def createRegion(self) -> 'XRegion_70f30910':
        """
        creates a region.
        """
    def createScreenCompatibleDevice(self, Width: int, Height: int) -> 'XDevice_70ba08fc':
        """
        creates a virtual device that is compatible with the screen.
        """
    def createWindow(self, Descriptor: 'WindowDescriptor_d61e0ceb') -> 'XWindowPeer_99760ab0':
        """
        creates a new window using the given descriptor.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createWindows(self, Descriptors: 'typing.Tuple[WindowDescriptor_d61e0ceb, ...]') -> 'typing.Tuple[XWindowPeer_99760ab0, ...]':
        """
        returns a sequence of windows which are newly created using the given descriptors.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getDesktopWindow(self) -> 'XWindowPeer_99760ab0':
        """
        returns the desktop window.
        """
    def getWorkArea(self) -> 'Rectangle_84b109e9':
        """
        For LibreOffice versions < 4.1, this method just returned an empty rectangle.
        
        After that, it started returning a valid value.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.dom
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .sax_document_builder_state import SAXDocumentBuilderState as SAXDocumentBuilderState_723f10ba
    from .x_document import XDocument as XDocument_aebc0b5e
    from .x_document_fragment import XDocumentFragment as XDocumentFragment_17850e92

class XSAXDocumentBuilder(XInterface_8f010a43):
    """
    Builds a new dom tree.

    See Also:
        `API XSAXDocumentBuilder <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XSAXDocumentBuilder.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.dom.XSAXDocumentBuilder']

    def endDocumentFragment(self) -> None:
        """
        """
    def getDocument(self) -> 'XDocument_aebc0b5e':
        """
        """
    def getDocumentFragment(self) -> 'XDocumentFragment_17850e92':
        """
        """
    def getState(self) -> 'SAXDocumentBuilderState_723f10ba':
        """
        """
    def reset(self) -> None:
        """
        """
    def startDocumentFragment(self, ownerDoc: 'XDocument_aebc0b5e') -> None:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .border_line import BorderLine as BorderLine_a3f80af6


class TableBorder(object):
    """
    Struct Class

    contains the style settings of the border lines of all cells in a cell range.
    
    In a queried structure, the flags in TableBorder.Is...LineValid indicate that not all lines of the boxes have the same values.
    
    In a structure which is used for setting, these flags determine if the corresponding line should be set or if the old value should be kept.

    See Also:
        `API TableBorder <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1TableBorder.html>`_
    """
    typeName: Literal['com.sun.star.table.TableBorder']

    def __init__(self, TopLine: typing.Optional[BorderLine_a3f80af6] = ..., IsTopLineValid: typing.Optional[bool] = ..., BottomLine: typing.Optional[BorderLine_a3f80af6] = ..., IsBottomLineValid: typing.Optional[bool] = ..., LeftLine: typing.Optional[BorderLine_a3f80af6] = ..., IsLeftLineValid: typing.Optional[bool] = ..., RightLine: typing.Optional[BorderLine_a3f80af6] = ..., IsRightLineValid: typing.Optional[bool] = ..., HorizontalLine: typing.Optional[BorderLine_a3f80af6] = ..., IsHorizontalLineValid: typing.Optional[bool] = ..., VerticalLine: typing.Optional[BorderLine_a3f80af6] = ..., IsVerticalLineValid: typing.Optional[bool] = ..., Distance: typing.Optional[int] = ..., IsDistanceValid: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            TopLine (BorderLine, optional): TopLine value.
            IsTopLineValid (bool, optional): IsTopLineValid value.
            BottomLine (BorderLine, optional): BottomLine value.
            IsBottomLineValid (bool, optional): IsBottomLineValid value.
            LeftLine (BorderLine, optional): LeftLine value.
            IsLeftLineValid (bool, optional): IsLeftLineValid value.
            RightLine (BorderLine, optional): RightLine value.
            IsRightLineValid (bool, optional): IsRightLineValid value.
            HorizontalLine (BorderLine, optional): HorizontalLine value.
            IsHorizontalLineValid (bool, optional): IsHorizontalLineValid value.
            VerticalLine (BorderLine, optional): VerticalLine value.
            IsVerticalLineValid (bool, optional): IsVerticalLineValid value.
            Distance (int, optional): Distance value.
            IsDistanceValid (bool, optional): IsDistanceValid value.
        """


    @property
    def TopLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the top edge.
        """


    @property
    def IsTopLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.TopLine is used.
        """


    @property
    def BottomLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the bottom edge.
        """


    @property
    def IsBottomLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.BottomLine is used.
        """


    @property
    def LeftLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the left edge.
        """


    @property
    def IsLeftLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.LeftLine is used.
        """


    @property
    def RightLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style at the right edge.
        """


    @property
    def IsRightLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.RightLine is used.
        """


    @property
    def HorizontalLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style of horizontal lines for the inner part of a cell range.
        """


    @property
    def IsHorizontalLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.HorizontalLine is used.
        """


    @property
    def VerticalLine(self) -> BorderLine_a3f80af6:
        """
        determines the line style of vertical lines for the inner part of a cell range.
        """


    @property
    def IsVerticalLineValid(self) -> bool:
        """
        specifies whether the value of TableBorder.VerticalLine is used.
        """


    @property
    def Distance(self) -> int:
        """
        contains the distance between the lines and other contents.
        """


    @property
    def IsDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.Distance is used.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.ucb.already_initialized_exception import AlreadyInitializedException as AlreadyInitializedException
from .._pyi.ucb.any_compare_factory import AnyCompareFactory as AnyCompareFactory
from .._pyi.ucb.authentication_fallback_request import AuthenticationFallbackRequest as AuthenticationFallbackRequest
from .._pyi.ucb.authentication_request import AuthenticationRequest as AuthenticationRequest
from .._pyi.ucb.cached_content_result_set import CachedContentResultSet as CachedContentResultSet
from .._pyi.ucb.cached_content_result_set_factory import CachedContentResultSetFactory as CachedContentResultSetFactory
from .._pyi.ucb.cached_content_result_set_stub import CachedContentResultSetStub as CachedContentResultSetStub
from .._pyi.ucb.cached_content_result_set_stub_factory import CachedContentResultSetStubFactory as CachedContentResultSetStubFactory
from .._pyi.ucb.cached_dynamic_result_set import CachedDynamicResultSet as CachedDynamicResultSet
from .._pyi.ucb.cached_dynamic_result_set_factory import CachedDynamicResultSetFactory as CachedDynamicResultSetFactory
from .._pyi.ucb.cached_dynamic_result_set_stub import CachedDynamicResultSetStub as CachedDynamicResultSetStub
from .._pyi.ucb.cached_dynamic_result_set_stub_factory import CachedDynamicResultSetStubFactory as CachedDynamicResultSetStubFactory
from .._pyi.ucb.certificate_validation_request import CertificateValidationRequest as CertificateValidationRequest
from .._pyi.ucb.checkin_argument import CheckinArgument as CheckinArgument
from .._pyi.ucb.cmis_content_provider import CmisContentProvider as CmisContentProvider
from .._pyi.ucb.command import Command as Command
from .._pyi.ucb.command_aborted_exception import CommandAbortedException as CommandAbortedException
from .._pyi.ucb.command_environment import CommandEnvironment as CommandEnvironment
from .._pyi.ucb.command_failed_exception import CommandFailedException as CommandFailedException
from .._pyi.ucb.command_info import CommandInfo as CommandInfo
from .._pyi.ucb.command_info_change_event import CommandInfoChangeEvent as CommandInfoChangeEvent
from .._pyi.ucb.content import Content as Content
from .._pyi.ucb.content_creation_exception import ContentCreationException as ContentCreationException
from .._pyi.ucb.content_event import ContentEvent as ContentEvent
from .._pyi.ucb.content_info import ContentInfo as ContentInfo
from .._pyi.ucb.content_provider import ContentProvider as ContentProvider
from .._pyi.ucb.content_provider_info import ContentProviderInfo as ContentProviderInfo
from .._pyi.ucb.content_provider_proxy import ContentProviderProxy as ContentProviderProxy
from .._pyi.ucb.content_provider_proxy_factory import ContentProviderProxyFactory as ContentProviderProxyFactory
from .._pyi.ucb.content_result_set import ContentResultSet as ContentResultSet
from .._pyi.ucb.content_transmitter import ContentTransmitter as ContentTransmitter
from .._pyi.ucb.cross_reference import CrossReference as CrossReference
from .._pyi.ucb.default_hierarchy_data_source import DefaultHierarchyDataSource as DefaultHierarchyDataSource
from .._pyi.ucb.document_header_field import DocumentHeaderField as DocumentHeaderField
from .._pyi.ucb.duplicate_command_identifier_exception import DuplicateCommandIdentifierException as DuplicateCommandIdentifierException
from .._pyi.ucb.duplicate_provider_exception import DuplicateProviderException as DuplicateProviderException
from .._pyi.ucb.dynamic_result_set import DynamicResultSet as DynamicResultSet
from .._pyi.ucb.expand_content_provider import ExpandContentProvider as ExpandContentProvider
from .._pyi.ucb.export_stream_info import ExportStreamInfo as ExportStreamInfo
from .._pyi.ucb.ftp_content import FTPContent as FTPContent
from .._pyi.ucb.ftp_content_provider import FTPContentProvider as FTPContentProvider
from .._pyi.ucb.fetch_result import FetchResult as FetchResult
from .._pyi.ucb.file_content import FileContent as FileContent
from .._pyi.ucb.file_content_provider import FileContentProvider as FileContentProvider
from .._pyi.ucb.folder_list import FolderList as FolderList
from .._pyi.ucb.folder_list_entry import FolderListEntry as FolderListEntry
from .._pyi.ucb.gio_content_provider import GIOContentProvider as GIOContentProvider
from .._pyi.ucb.global_transfer_command_argument import GlobalTransferCommandArgument as GlobalTransferCommandArgument
from .._pyi.ucb.global_transfer_command_argument2 import GlobalTransferCommandArgument2 as GlobalTransferCommandArgument2
from .._pyi.ucb.gnome_vfs_content_provider import GnomeVFSContentProvider as GnomeVFSContentProvider
from .._pyi.ucb.gnome_vfs_document_content import GnomeVFSDocumentContent as GnomeVFSDocumentContent
from .._pyi.ucb.gnome_vfs_folder_content import GnomeVFSFolderContent as GnomeVFSFolderContent
from .._pyi.ucb.help_content import HelpContent as HelpContent
from .._pyi.ucb.help_content_provider import HelpContentProvider as HelpContentProvider
from .._pyi.ucb.hierarchy_content_provider import HierarchyContentProvider as HierarchyContentProvider
from .._pyi.ucb.hierarchy_data_read_access import HierarchyDataReadAccess as HierarchyDataReadAccess
from .._pyi.ucb.hierarchy_data_read_write_access import HierarchyDataReadWriteAccess as HierarchyDataReadWriteAccess
from .._pyi.ucb.hierarchy_data_source import HierarchyDataSource as HierarchyDataSource
from .._pyi.ucb.hierarchy_folder_content import HierarchyFolderContent as HierarchyFolderContent
from .._pyi.ucb.hierarchy_link_content import HierarchyLinkContent as HierarchyLinkContent
from .._pyi.ucb.hierarchy_root_folder_content import HierarchyRootFolderContent as HierarchyRootFolderContent
from .._pyi.ucb.illegal_identifier_exception import IllegalIdentifierException as IllegalIdentifierException
from .._pyi.ucb.insert_command_argument import InsertCommandArgument as InsertCommandArgument
from .._pyi.ucb.insert_command_argument2 import InsertCommandArgument2 as InsertCommandArgument2
from .._pyi.ucb.interactive_app_exception import InteractiveAppException as InteractiveAppException
from .._pyi.ucb.interactive_augmented_io_exception import InteractiveAugmentedIOException as InteractiveAugmentedIOException
from .._pyi.ucb.interactive_bad_transfer_url_exception import InteractiveBadTransferURLException as InteractiveBadTransferURLException
from .._pyi.ucb.interactive_file_io_exception import InteractiveFileIOException as InteractiveFileIOException
from .._pyi.ucb.interactive_io_exception import InteractiveIOException as InteractiveIOException
from .._pyi.ucb.interactive_locking_exception import InteractiveLockingException as InteractiveLockingException
from .._pyi.ucb.interactive_locking_lock_expired_exception import InteractiveLockingLockExpiredException as InteractiveLockingLockExpiredException
from .._pyi.ucb.interactive_locking_locked_exception import InteractiveLockingLockedException as InteractiveLockingLockedException
from .._pyi.ucb.interactive_locking_not_locked_exception import InteractiveLockingNotLockedException as InteractiveLockingNotLockedException
from .._pyi.ucb.interactive_network_connect_exception import InteractiveNetworkConnectException as InteractiveNetworkConnectException
from .._pyi.ucb.interactive_network_exception import InteractiveNetworkException as InteractiveNetworkException
from .._pyi.ucb.interactive_network_general_exception import InteractiveNetworkGeneralException as InteractiveNetworkGeneralException
from .._pyi.ucb.interactive_network_off_line_exception import InteractiveNetworkOffLineException as InteractiveNetworkOffLineException
from .._pyi.ucb.interactive_network_read_exception import InteractiveNetworkReadException as InteractiveNetworkReadException
from .._pyi.ucb.interactive_network_resolve_name_exception import InteractiveNetworkResolveNameException as InteractiveNetworkResolveNameException
from .._pyi.ucb.interactive_network_write_exception import InteractiveNetworkWriteException as InteractiveNetworkWriteException
from .._pyi.ucb.interactive_wrong_medium_exception import InteractiveWrongMediumException as InteractiveWrongMediumException
from .._pyi.ucb.link import Link as Link
from .._pyi.ucb.list_action import ListAction as ListAction
from .._pyi.ucb.list_event import ListEvent as ListEvent
from .._pyi.ucb.listener_already_set_exception import ListenerAlreadySetException as ListenerAlreadySetException
from .._pyi.ucb.lock import Lock as Lock
from .._pyi.ucb.lock_entry import LockEntry as LockEntry
from .._pyi.ucb.missing_input_stream_exception import MissingInputStreamException as MissingInputStreamException
from .._pyi.ucb.missing_properties_exception import MissingPropertiesException as MissingPropertiesException
from .._pyi.ucb.name_clash_exception import NameClashException as NameClashException
from .._pyi.ucb.name_clash_resolve_request import NameClashResolveRequest as NameClashResolveRequest
from .._pyi.ucb.numbered_sorting_info import NumberedSortingInfo as NumberedSortingInfo
from .._pyi.ucb.odma_content import ODMAContent as ODMAContent
from .._pyi.ucb.odma_content_provider import ODMAContentProvider as ODMAContentProvider
from .._pyi.ucb.open_command_argument import OpenCommandArgument as OpenCommandArgument
from .._pyi.ucb.open_command_argument2 import OpenCommandArgument2 as OpenCommandArgument2
from .._pyi.ucb.open_command_argument3 import OpenCommandArgument3 as OpenCommandArgument3
from .._pyi.ucb.package_content_provider import PackageContentProvider as PackageContentProvider
from .._pyi.ucb.package_folder_content import PackageFolderContent as PackageFolderContent
from .._pyi.ucb.package_stream_content import PackageStreamContent as PackageStreamContent
from .._pyi.ucb.persistent_property_set import PersistentPropertySet as PersistentPropertySet
from .._pyi.ucb.post_command_argument import PostCommandArgument as PostCommandArgument
from .._pyi.ucb.post_command_argument2 import PostCommandArgument2 as PostCommandArgument2
from .._pyi.ucb.properties_manager import PropertiesManager as PropertiesManager
from .._pyi.ucb.property_command_argument import PropertyCommandArgument as PropertyCommandArgument
from .._pyi.ucb.property_set_registry import PropertySetRegistry as PropertySetRegistry
from .._pyi.ucb.property_value_info import PropertyValueInfo as PropertyValueInfo
from .._pyi.ucb.recipient_info import RecipientInfo as RecipientInfo
from .._pyi.ucb.remote_access_content_provider import RemoteAccessContentProvider as RemoteAccessContentProvider
from .._pyi.ucb.remote_content_provider_acceptor import RemoteContentProviderAcceptor as RemoteContentProviderAcceptor
from .._pyi.ucb.remote_content_provider_change_event import RemoteContentProviderChangeEvent as RemoteContentProviderChangeEvent
from .._pyi.ucb.remote_proxy_content_provider import RemoteProxyContentProvider as RemoteProxyContentProvider
from .._pyi.ucb.result_set_exception import ResultSetException as ResultSetException
from .._pyi.ucb.rule import Rule as Rule
from .._pyi.ucb.rule_set import RuleSet as RuleSet
from .._pyi.ucb.rule_term import RuleTerm as RuleTerm
from .._pyi.ucb.search_command_argument import SearchCommandArgument as SearchCommandArgument
from .._pyi.ucb.search_criterium import SearchCriterium as SearchCriterium
from .._pyi.ucb.search_info import SearchInfo as SearchInfo
from .._pyi.ucb.send_info import SendInfo as SendInfo
from .._pyi.ucb.send_media_types import SendMediaTypes as SendMediaTypes
from .._pyi.ucb.service_not_found_exception import ServiceNotFoundException as ServiceNotFoundException
from .._pyi.ucb.simple_file_access import SimpleFileAccess as SimpleFileAccess
from .._pyi.ucb.sorted_dynamic_result_set_factory import SortedDynamicResultSetFactory as SortedDynamicResultSetFactory
from .._pyi.ucb.sorting_info import SortingInfo as SortingInfo
from .._pyi.ucb.store import Store as Store
from .._pyi.ucb.transfer_info import TransferInfo as TransferInfo
from .._pyi.ucb.transfer_info2 import TransferInfo2 as TransferInfo2
from .._pyi.ucb.transfer_result import TransferResult as TransferResult
from .._pyi.ucb.transient_documents_content_provider import TransientDocumentsContentProvider as TransientDocumentsContentProvider
from .._pyi.ucb.transient_documents_document_content import TransientDocumentsDocumentContent as TransientDocumentsDocumentContent
from .._pyi.ucb.transient_documents_folder_content import TransientDocumentsFolderContent as TransientDocumentsFolderContent
from .._pyi.ucb.transient_documents_root_content import TransientDocumentsRootContent as TransientDocumentsRootContent
from .._pyi.ucb.transient_documents_stream_content import TransientDocumentsStreamContent as TransientDocumentsStreamContent
from .._pyi.ucb.url_authentication_request import URLAuthenticationRequest as URLAuthenticationRequest
from .._pyi.ucb.universal_content_broker import UniversalContentBroker as UniversalContentBroker
from .._pyi.ucb.unsupported_command_exception import UnsupportedCommandException as UnsupportedCommandException
from .._pyi.ucb.unsupported_data_sink_exception import UnsupportedDataSinkException as UnsupportedDataSinkException
from .._pyi.ucb.unsupported_name_clash_exception import UnsupportedNameClashException as UnsupportedNameClashException
from .._pyi.ucb.unsupported_open_mode_exception import UnsupportedOpenModeException as UnsupportedOpenModeException
from .._pyi.ucb.web_dav_content_provider import WebDAVContentProvider as WebDAVContentProvider
from .._pyi.ucb.web_dav_document_content import WebDAVDocumentContent as WebDAVDocumentContent
from .._pyi.ucb.web_dav_folder_content import WebDAVFolderContent as WebDAVFolderContent
from .._pyi.ucb.welcome_dynamic_result_set_struct import WelcomeDynamicResultSetStruct as WelcomeDynamicResultSetStruct
from .._pyi.ucb.x_any_compare import XAnyCompare as XAnyCompare
from .._pyi.ucb.x_any_compare_factory import XAnyCompareFactory as XAnyCompareFactory
from .._pyi.ucb.x_cached_content_result_set_factory import XCachedContentResultSetFactory as XCachedContentResultSetFactory
from .._pyi.ucb.x_cached_content_result_set_stub_factory import XCachedContentResultSetStubFactory as XCachedContentResultSetStubFactory
from .._pyi.ucb.x_cached_dynamic_result_set_factory import XCachedDynamicResultSetFactory as XCachedDynamicResultSetFactory
from .._pyi.ucb.x_cached_dynamic_result_set_stub_factory import XCachedDynamicResultSetStubFactory as XCachedDynamicResultSetStubFactory
from .._pyi.ucb.x_command_environment import XCommandEnvironment as XCommandEnvironment
from .._pyi.ucb.x_command_info import XCommandInfo as XCommandInfo
from .._pyi.ucb.x_command_info_change_listener import XCommandInfoChangeListener as XCommandInfoChangeListener
from .._pyi.ucb.x_command_info_change_notifier import XCommandInfoChangeNotifier as XCommandInfoChangeNotifier
from .._pyi.ucb.x_command_processor import XCommandProcessor as XCommandProcessor
from .._pyi.ucb.x_command_processor2 import XCommandProcessor2 as XCommandProcessor2
from .._pyi.ucb.x_content import XContent as XContent
from .._pyi.ucb.x_content_access import XContentAccess as XContentAccess
from .._pyi.ucb.x_content_creator import XContentCreator as XContentCreator
from .._pyi.ucb.x_content_event_listener import XContentEventListener as XContentEventListener
from .._pyi.ucb.x_content_identifier import XContentIdentifier as XContentIdentifier
from .._pyi.ucb.x_content_identifier_factory import XContentIdentifierFactory as XContentIdentifierFactory
from .._pyi.ucb.x_content_identifier_mapping import XContentIdentifierMapping as XContentIdentifierMapping
from .._pyi.ucb.x_content_provider import XContentProvider as XContentProvider
from .._pyi.ucb.x_content_provider_factory import XContentProviderFactory as XContentProviderFactory
from .._pyi.ucb.x_content_provider_manager import XContentProviderManager as XContentProviderManager
from .._pyi.ucb.x_content_provider_supplier import XContentProviderSupplier as XContentProviderSupplier
from .._pyi.ucb.x_content_transmitter import XContentTransmitter as XContentTransmitter
from .._pyi.ucb.x_data_container import XDataContainer as XDataContainer
from .._pyi.ucb.x_dynamic_result_set import XDynamicResultSet as XDynamicResultSet
from .._pyi.ucb.x_dynamic_result_set_listener import XDynamicResultSetListener as XDynamicResultSetListener
from .._pyi.ucb.x_fetch_provider import XFetchProvider as XFetchProvider
from .._pyi.ucb.x_fetch_provider_for_content_access import XFetchProviderForContentAccess as XFetchProviderForContentAccess
from .._pyi.ucb.x_file_identifier_converter import XFileIdentifierConverter as XFileIdentifierConverter
from .._pyi.ucb.x_interaction_auth_fallback import XInteractionAuthFallback as XInteractionAuthFallback
from .._pyi.ucb.x_interaction_handler_supplier import XInteractionHandlerSupplier as XInteractionHandlerSupplier
from .._pyi.ucb.x_interaction_replace_existing_data import XInteractionReplaceExistingData as XInteractionReplaceExistingData
from .._pyi.ucb.x_interaction_supply_authentication import XInteractionSupplyAuthentication as XInteractionSupplyAuthentication
from .._pyi.ucb.x_interaction_supply_authentication2 import XInteractionSupplyAuthentication2 as XInteractionSupplyAuthentication2
from .._pyi.ucb.x_interaction_supply_name import XInteractionSupplyName as XInteractionSupplyName
from .._pyi.ucb.x_parameterized_content_provider import XParameterizedContentProvider as XParameterizedContentProvider
from .._pyi.ucb.x_persistent_property_set import XPersistentPropertySet as XPersistentPropertySet
from .._pyi.ucb.x_progress_handler import XProgressHandler as XProgressHandler
from .._pyi.ucb.x_property_matcher import XPropertyMatcher as XPropertyMatcher
from .._pyi.ucb.x_property_matcher_factory import XPropertyMatcherFactory as XPropertyMatcherFactory
from .._pyi.ucb.x_property_set_registry import XPropertySetRegistry as XPropertySetRegistry
from .._pyi.ucb.x_property_set_registry_factory import XPropertySetRegistryFactory as XPropertySetRegistryFactory
from .._pyi.ucb.x_recycler import XRecycler as XRecycler
from .._pyi.ucb.x_remote_content_provider_acceptor import XRemoteContentProviderAcceptor as XRemoteContentProviderAcceptor
from .._pyi.ucb.x_remote_content_provider_activator import XRemoteContentProviderActivator as XRemoteContentProviderActivator
from .._pyi.ucb.x_remote_content_provider_change_listener import XRemoteContentProviderChangeListener as XRemoteContentProviderChangeListener
from .._pyi.ucb.x_remote_content_provider_change_notifier import XRemoteContentProviderChangeNotifier as XRemoteContentProviderChangeNotifier
from .._pyi.ucb.x_remote_content_provider_connection_control import XRemoteContentProviderConnectionControl as XRemoteContentProviderConnectionControl
from .._pyi.ucb.x_remote_content_provider_distributor import XRemoteContentProviderDistributor as XRemoteContentProviderDistributor
from .._pyi.ucb.x_remote_content_provider_done_listener import XRemoteContentProviderDoneListener as XRemoteContentProviderDoneListener
from .._pyi.ucb.x_remote_content_provider_supplier import XRemoteContentProviderSupplier as XRemoteContentProviderSupplier
from .._pyi.ucb.x_simple_file_access import XSimpleFileAccess as XSimpleFileAccess
from .._pyi.ucb.x_simple_file_access2 import XSimpleFileAccess2 as XSimpleFileAccess2
from .._pyi.ucb.x_simple_file_access3 import XSimpleFileAccess3 as XSimpleFileAccess3
from .._pyi.ucb.x_sorted_dynamic_result_set_factory import XSortedDynamicResultSetFactory as XSortedDynamicResultSetFactory
from .._pyi.ucb.x_source_initialization import XSourceInitialization as XSourceInitialization
from .._pyi.ucb.x_universal_content_broker import XUniversalContentBroker as XUniversalContentBroker
from .._pyi.ucb.x_web_dav_command_environment import XWebDAVCommandEnvironment as XWebDAVCommandEnvironment



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.beans
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_introspection_access import XIntrospectionAccess as XIntrospectionAccess_2a050f2c

class XIntrospection(XInterface_8f010a43):
    """
    allows the inspection of an object's properties and methods.
    
    Important note:An object can only be inspected completely if it supports the com.sun.star.lang.XTypeProvider interface.
    
    For details see method XIntrospection.inspect().

    See Also:
        `API XIntrospection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XIntrospection.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.beans.XIntrospection']

    def inspect(self, aObject: object) -> 'XIntrospectionAccess_2a050f2c':
        """
        inspects the given object.
        
        It identifies all properties supported by the object if they are represented in one of the following ways:
        
        In addition, the inspect method identifies all listener access methods in the form add...Listener/ remove...Listener (except methods of interface XPropertySet) where \"...\" stands for the listener type.
        
        Methods which do not belong to a property nor which represent a listener access nor which are methods of XPropertySet, com.sun.star.container.XNameAccess, com.sun.star.container.XIndexAccess, or com.sun.star.container.XEnumerationAccess, are considered to be normal methods.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from .x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from .x_accessible_event_broadcaster import XAccessibleEventBroadcaster as XAccessibleEventBroadcaster_3d811522

class AccessibleContext(XAccessibleContext_8eae119b, XAccessibleEventBroadcaster_3d811522):
    """
    Service Class

    Central service of the Accessibility API that gives access to various facets of an object's content.
    
    This service has to be implemented by every class that represents the actual accessibility information of another UNO service. It exposes two kinds of information: A tree structure in which all accessible objects are organized can be navigated in freely. It typically represents spatial relationship of one object containing a set of children like a dialog box contains a set of buttons. Additionally the XAccessibleContext interface of this service exposes methods that provide access to the actual object's content. This can be the object's role, name, description, and so on.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleContext <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1accessibility_1_1AccessibleContext.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .key_event import KeyEvent as KeyEvent_7a78097f
    from .mouse_event import MouseEvent as MouseEvent_8f430a5f

class XToolkitRobot(ABC):
    """
    Allows injection of keyboard and mouse events.
    
    **since**
    
        LibreOffice 5.1

    See Also:
        `API XToolkitRobot <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitRobot.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XToolkitRobot']

    def keyPress(self, aKeyEvent: 'KeyEvent_7a78097f') -> None:
        """
        """
    def keyRelease(self, aKeyEvent: 'KeyEvent_7a78097f') -> None:
        """
        """
    def mouseMove(self, aMouseEvent: 'MouseEvent_8f430a5f') -> None:
        """
        """
    def mousePress(self, aMouseEvent: 'MouseEvent_8f430a5f') -> None:
        """
        """
    def mouseRelease(self, aMouseEvent: 'MouseEvent_8f430a5f') -> None:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from .x_single_select_query_analyzer import XSingleSelectQueryAnalyzer as XSingleSelectQueryAnalyzer_66ad10b7
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XSingleSelectQueryComposer(XSingleSelectQueryAnalyzer_66ad10b7):
    """
    simplifies the composing of single select statements.
    
    The interface can be used for composing single SELECT statements without knowing the structure of the used query.

    See Also:
        `API XSingleSelectQueryComposer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XSingleSelectQueryComposer']

    def appendFilterByColumn(self, column: 'XPropertySet_bc180bfa', andCriteria: bool, filterOperator: int) -> None:
        """
        appends a new filter condition by a com.sun.star.sdb.DataColumn providing the name and the value for the filter.
        
        The value property must be supported by the com.sun.star.sdb.DataColumn.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def appendGroupByColumn(self, column: 'XPropertySet_bc180bfa') -> None:
        """
        appends an additional part to the group criteria of the select statement.
        
        The column must be a com.sun.star.sdbcx.Column.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def appendHavingClauseByColumn(self, column: 'XPropertySet_bc180bfa', andCriteria: bool, filterOperator: int) -> None:
        """
        appends a new HAVING filter condition by a com.sun.star.sdb.DataColumn providing the name and the value for the filter.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def appendOrderByColumn(self, column: 'XPropertySet_bc180bfa', ascending: bool) -> None:
        """
        appends an additional part to the sort order criteria of the select statement.
        
        The column must be a com.sun.star.sdbcx.Column.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def setFilter(self, filter: str) -> None:
        """
        makes it possible to set a filter condition for the query.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def setGroup(self, group: str) -> None:
        """
        makes it possible to set a group for the query.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def setHavingClause(self, filter: str) -> None:
        """
        makes it possible to set a HAVING filter condition for the query.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def setOrder(self, order: str) -> None:
        """
        makes it possible to set a sort condition for the query.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def setStructuredFilter(self, filter: 'typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]') -> None:
        """
        appends a new set of filter criteria which is split into levels.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setStructuredHavingClause(self, filter: 'typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]') -> None:
        """
        appends a new set of HAVING filter criteria which is split into levels.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    @property
    def ElementaryQuery(self) -> str:
        """
        sets a new elementary query for the composer
        
        An elementary query or statement is a (single select) statement whose parts are not covered by the various set and get methods of the composer. That is, if the elementary statement contains a filter clause, a call to XSingleSelectQueryAnalyzer.getFilter() will not return you this filter. Instead, only filters which have been set using for instance setFilter() are covered by the get methods.
        
        The only methods which take all parts of the elementary statement into account are XSingleSelectQueryAnalyzer.getQuery() and XSingleSelectQueryAnalyzer.getQueryWithSubstitution(), which always returns the complete composed query.
        
        As a result, you can use the composer to build cumulative filter expressions. That is, you can set ElementaryQuery to a statement already containing filters, and then use setFilter() to append additional filters.
        
        The very same holds for sort orders, HAVING and GROUP BY clauses.
        
        There are various use cases for this. For instance, you might want to use the statement represented by a QueryDefinition, and extend it with additional filters or sort orders, while not touching the respective parts already present in QueryDefinition.Command. This can be achieved by setting the QueryDefinition.Command as ElementaryQuery of a SingleSelectQueryComposer.
        
        If, in such a scenario, you would be interested in the filter part of the QueryDefinition.Command, you would set it via XSingleSelectQueryAnalyzer.setQuery(), and retrieve the filter part via XSingleSelectQueryAnalyzer.getFilter().
        
        If you'd be interested in the composed filter, you would set the QueryDefinition.Command as ElementaryQuery, add your filter, and propagate the resulting query (XSingleSelectQueryAnalyzer.getQuery()) to an SingleSelectQueryAnalyzer instance via XSingleSelectQueryAnalyzer.setQuery().
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.gradient import Gradient as Gradient_7a8a0982
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909
    from .bitmap_mode import BitmapMode as BitmapMode_bced0bd6
    from .fill_style import FillStyle as FillStyle_b1460b8c
    from .hatch import Hatch as Hatch_859b09dc
    from .rectangle_point import RectanglePoint as RectanglePoint_f0ff0d93
    from ..text.graphic_crop import GraphicCrop as GraphicCrop_a58e0b1f
    from ..util.color import Color as Color_68e908c5

class FillProperties(ABC):
    """
    Service Class

    This is a set of properties to describe the style for rendering an area.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API FillProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1FillProperties.html>`_
    """
    @property
    def FillBackground(self) -> bool:
        """
        if this is TRUE, the transparent background of a hatch filled area is drawn in the current background color.
        """
    @property
    def FillBitmap(self) -> 'XBitmap_70cd0909':
        """
        If the property FillStyle is set to FillStyle.BITMAP, this is the bitmap used.
        """
    @property
    def FillBitmapLogicalSize(self) -> bool:
        """
        specifies if the size is given in percentage or as an absolute value.
        
        If this is TRUE, the properties FillBitmapSizeX and FillBitmapSizeY contain the size of the tile in percent of the size of the original bitmap. If this is FALSE, the size of the tile is specified with 1/100th mm.
        """
    @property
    def FillBitmapMode(self) -> 'BitmapMode_bced0bd6':
        """
        this enum selects how an area is filled with a single bitmap.
        
        This property corresponds to the properties FillBitmapStretch and FillBitmapTile.
        
        If set to BitmapMode.REPEAT, the property FillBitmapStretch is set to FALSE, and the property FillBitmapTile is set to TRUE.
        
        If set to BitmapMode.STRETCH, the property FillBitmapStretch is set to TRUE, and the property FillBitmapTile is set to FALSE.
        
        If set to BitmapMode.NO_REPEAT, both properties FillBitmapStretch and FillBitmapTile are set to FALSE.
        """
    @property
    def FillBitmapName(self) -> str:
        """
        If the property FillStyle is set to FillStyle.BITMAP, this is the name of the used fill bitmap style.
        """
    @property
    def FillBitmapOffsetX(self) -> int:
        """
        Every second line of tiles is moved the given percent of the width of the bitmap.
        """
    @property
    def FillBitmapOffsetY(self) -> int:
        """
        Every second row of tiles is moved the given percent of the height of the bitmap.
        """
    @property
    def FillBitmapPositionOffsetX(self) -> int:
        """
        This is the horizontal offset where the tile starts.
        
        It is given in percent in relation to the width of the bitmap.
        """
    @property
    def FillBitmapPositionOffsetY(self) -> int:
        """
        This is the vertical offset where the tile starts.
        
        It is given in percent in relation to the height of the bitmap.
        """
    @property
    def FillBitmapRectanglePoint(self) -> 'RectanglePoint_f0ff0d93':
        """
        The RectanglePoint specifies the position inside of the bitmap to use as the top left position for rendering.
        """
    @property
    def FillBitmapSizeX(self) -> int:
        """
        This is the width of the tile for filling.
        
        Depending on the property FillBitmapLogicalSize, this is either relative or absolute.
        """
    @property
    def FillBitmapSizeY(self) -> int:
        """
        This is the height of the tile for filling.
        
        Depending on the property FillBitmapLogicalSize, this is either relative or absolute.
        """
    @property
    def FillBitmapStretch(self) -> bool:
        """
        if set, the fill bitmap is stretched to fill the area of the shape.
        
        This property should not be used anymore and is included here for completeness. The FillBitmapMode property can be used instead to set all supported bitmap modes.
        
        If set to TRUE, the value of the FillBitmapMode property changes to BitmapMode.STRETCH. BUT: behavior is undefined, if the property FillBitmapTile is TRUE too.
        
        If set to FALSE, the value of the FillBitmapMode property changes to BitmapMode.REPEAT or BitmapMode.NO_REPEAT, depending on the current value of the FillBitmapTile property.
        """
    @property
    def FillBitmapTile(self) -> bool:
        """
        if set, the fill bitmap is repeated to fill the area of the shape.
        
        This property should not be used anymore and is included here for completeness. The FillBitmapMode property can be used instead to set all supported bitmap modes.
        
        If set to TRUE, the value of the FillBitmapMode property changes to BitmapMode.REPEAT. BUT: behavior is undefined, if the property FillBitmapStretch is TRUE too.
        
        If set to FALSE, the value of the FillBitmapMode property changes to BitmapMode.STRETCH or BitmapMode.NO_REPEAT, depending on the current value of the FillBitmapStretch property.
        """
    @property
    def FillBitmapURL(self) -> str:
        """
        If the property FillStyle is set to FillStyle.BITMAP, this is a URL to the bitmap used.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When a URL is set, then it will load the bitmap and set the FillBitmap property.
        """
    @property
    def FillColor(self) -> 'Color_68e908c5':
        """
        If the property FillStyle is set to FillStyle.SOLID, this is the color used.
        """
    @property
    def FillGradient(self) -> 'Gradient_7a8a0982':
        """
        If the property FillStyle is set to FillStyle.GRADIENT, this describes the gradient used.
        """
    @property
    def FillGradientName(self) -> str:
        """
        If the property FillStyle is set to FillStyle.GRADIENT, this is the name of the used fill gradient style.
        """
    @property
    def FillHatch(self) -> 'Hatch_859b09dc':
        """
        If the property FillStyle is set to FillStyle.HATCH, this describes the hatch used.
        """
    @property
    def FillHatchName(self) -> str:
        """
        If the property FillStyle is set to FillStyle.HATCH, this is the name of the used fill hatch style.
        """
    @property
    def FillStyle(self) -> 'FillStyle_b1460b8c':
        """
        This enumeration selects the style the area will be filled with.
        """
    @property
    def FillTransparence(self) -> int:
        """
        This is the transparence of the filled area.
        
        This property is only valid if the property FillStyle is set to FillStyle.SOLID.
        """
    @property
    def FillTransparenceGradient(self) -> 'Gradient_7a8a0982':
        """
        This describes the transparency of the fill area as a gradient.
        """
    @property
    def FillTransparenceGradientName(self) -> str:
        """
        If a gradient is used for transparency, this is the name of the used transparence gradient style or it is empty.
        
        If you set the name of a transparence gradient style contained in the document, this style used.
        """
    @property
    def GraphicCrop(self) -> 'GraphicCrop_a58e0b1f':
        """
        contains the cropping of the object.
        
        If the property FillBitmapMode is set to BitmapMode.STRETCH, this is the cropping, otherwise it is empty.
        
        **since**
        
            LibreOffice 4.3
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
"""
Const

This structure describes format of a floating point bitmap.

**since**

    OOo 2.0

See Also:
    `API FloatingPointBitmapFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1FloatingPointBitmapFormat.html>`_
"""
HALFFLOAT: Literal[0]
"""
Half-float format.

The color components are stored in the half-float format, i.e. in a 16 bit value, with 5 bit exponent, 10 bit mantissa and a sign bit. See also OpenEXR for a format employing half-floats.
"""
FLOAT: Literal[1]
"""
IEEE float format.

The color components are stored in the IEEE single-precision floating point format, i.e. in a 32 bit value, with 8 bit exponent, 23 bit mantissa and a sign bit.
"""
DOUBLE: Literal[2]
"""
IEEE double format.

The color components are stored in the IEEE double-precision floating point format, i.e. in a 64 bit value, with 16 bit exponent, 47 bit mantissa and a sign bit.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_action_listener import XActionListener as XActionListener_c7560c50
    from .x_item_listener import XItemListener as XItemListener_af710b81

class XListBox(XInterface_8f010a43):
    """
    gives access to the items of a list box and makes it possible to register item and action event listeners.

    See Also:
        `API XListBox <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XListBox']

    def addActionListener(self, l: 'XActionListener_c7560c50') -> None:
        """
        registers a listener for action events.
        """
    def addItem(self, aItem: str, nPos: int) -> None:
        """
        adds an item at the specified position.
        """
    def addItemListener(self, l: 'XItemListener_af710b81') -> None:
        """
        registers a listener for item events.
        """
    def addItems(self, aItems: 'typing.Tuple[str, ...]', nPos: int) -> None:
        """
        adds multiple items at the specified position.
        """
    def getDropDownLineCount(self) -> int:
        """
        returns the number of visible lines in drop down mode.
        """
    def getItem(self, nPos: int) -> str:
        """
        returns the item at the specified position.
        """
    def getItemCount(self) -> int:
        """
        returns the number of items in the listbox.
        """
    def getItems(self) -> 'typing.Tuple[str, ...]':
        """
        returns all items of the list box.
        """
    def getSelectedItem(self) -> str:
        """
        returns the currently selected item.
        
        When multiple items are selected, the first one is returned. When nothing is selected, an empty string is returned.
        """
    def getSelectedItemPos(self) -> int:
        """
        returns the position of the currently selected item.
        
        When multiple items are selected, the position of the first one is returned. When nothing is selected, -1 is returned.
        """
    def getSelectedItems(self) -> 'typing.Tuple[str, ...]':
        """
        returns all currently selected items.
        """
    def getSelectedItemsPos(self) -> 'typing.Tuple[int, ...]':
        """
        returns the positions of all currently selected items.
        """
    def isMutipleMode(self) -> bool:
        """
        returns TRUE if multiple items can be selected, FALSE if only one item can be selected.
        """
    def makeVisible(self, nEntry: int) -> None:
        """
        makes the item at the specified position visible by scrolling.
        """
    def removeActionListener(self, l: 'XActionListener_c7560c50') -> None:
        """
        unregisters a listener for action events.
        """
    def removeItemListener(self, l: 'XItemListener_af710b81') -> None:
        """
        unregisters a listener for item events.
        """
    def removeItems(self, nPos: int, nCount: int) -> None:
        """
        removes a number of items at the specified position.
        """
    def selectItem(self, aItem: str, bSelect: bool) -> None:
        """
        selects/deselects the specified item.
        """
    def selectItemPos(self, nPos: int, bSelect: bool) -> None:
        """
        selects/deselects the item at the specified position.
        """
    def selectItemsPos(self, aPositions: 'typing.Tuple[int, ...]', bSelect: bool) -> None:
        """
        selects/deselects multiple items at the specified positions.
        """
    def setDropDownLineCount(self, nLines: int) -> None:
        """
        sets the number of visible lines for drop down mode.
        """
    def setMultipleMode(self, bMulti: bool) -> None:
        """
        determines if only a single item or multiple items can be selected.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class DataPilotTablePositionType(object):
    """
    Const

    specifies in which sub-area a cell is positioned within a DataPilot table.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTablePositionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html>`_
    """
    NOT_IN_TABLE: Literal[0]
    """
    indicates that the specified cell is not in the DataPilot table.
    """
    RESULT: Literal[1]
    """
    indicates that the specified cell is within the result area.
    """
    ROW_HEADER: Literal[2]
    """
    indicates that the specified cell is within the row header area.
    """
    COLUMN_HEADER: Literal[3]
    """
    indicates that the specified cell is within the column header area.
    """
    OTHER: Literal[4]
    """
    indicates that the specified cell is within the table but in areas other than the result or header areas.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
import typing
from ..awt.x_window import XWindow as XWindow_713b0924
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_draw_view import XDrawView as XDrawView_b0b80b75
from ..frame.controller import Controller as Controller_a5330b37
from ..view.x_form_layer_access import XFormLayerAccess as XFormLayerAccess_e12f0cfe
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from .x_draw_page import XDrawPage as XDrawPage_b07a0b57

class DrawingDocumentDrawView(Controller_a5330b37, XWindow_713b0924, XPropertySet_bc180bfa, XDrawView_b0b80b75, XFormLayerAccess_e12f0cfe):
    """
    Service Class

    This component integrates a view to a DrawPages or MasterPage from a DrawingDocument.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DrawingDocumentDrawView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentDrawView.html>`_
    """
    @property
    def CurrentPage(self) -> 'XDrawPage_b07a0b57':
        """
        This is the drawing page that is currently visible.
        """
    @property
    def IsLayerMode(self) -> bool:
        """
        If the view is in layer mode, the user can modify the layer of the model of this view in the user interface.
        """
    @property
    def IsMasterPageMode(self) -> bool:
        """
        If the view is in master page mode, the view shows the master pages of this model.
        """
    @property
    def ViewOffset(self) -> 'Point_5fb2085e':
        """
        defines the offset from the top left position of the displayed page to the top left position of the view area in 100th/mm.
        
        **since**
        
            OOo 1.1.2
        """
    @property
    def VisibleArea(self) -> 'Rectangle_84b109e9':
        """
        This is the area that is currently visible.
        """
    @property
    def ZoomType(self) -> int:
        """
        This property defines the zoom type for the document.
        
        Note: After setting other types then com.sun.star.view.DocumentZoomType.BY_VALUE, implementations may calculate the required zoom value and set the type to com.sun.star.view.DocumentZoomType.BY_VALUE afterwards.
        
        **since**
        
            OOo 1.1.2
        """
    @property
    def ZoomValue(self) -> int:
        """
        Defines the zoom value to use.
        
        Valid only if the ZoomType is set to com.sun.star.view.DocumentZoomType.BY_VALUE.
        
        **since**
        
            OOo 1.1.2
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43


class FocusEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies a keyboard focus event.
    
    There are two levels of focus change events: permanent and temporary. Permanent focus change events occur when focus is directly moved from one component to another, such as through calls to requestFocus() or as the user uses the Tab key to traverse components. Temporary focus change events occur when focus is gained or lost for a component as the indirect result of another operation, such as window deactivation or a scrollbar drag. In this case, the original focus state will automatically be restored once that operation is finished, or for the case of window deactivation, when the window is reactivated. Both permanent and temporary focus events are delivered using the FOCUS_GAINED and FOCUS_LOST event ids; the levels may be distinguished in the event using the isTemporary() method.

    See Also:
        `API FocusEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1FocusEvent.html>`_
    """
    typeName: Literal['com.sun.star.awt.FocusEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., FocusFlags: typing.Optional[int] = ..., NextFocus: typing.Optional[XInterface_8f010a43] = ..., Temporary: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            FocusFlags (int, optional): FocusFlags value.
            NextFocus (XInterface, optional): NextFocus value.
            Temporary (bool, optional): Temporary value.
        """


    @property
    def FocusFlags(self) -> int:
        """
        specifies the reason for the focus change as an arithmetic-or combination of FocusChangeReason.
        """


    @property
    def NextFocus(self) -> XInterface_8f010a43:
        """
        contains the window which gets the focus on a lose focus event.
        """


    @property
    def Temporary(self) -> bool:
        """
        specifies if this focus change event is a temporary change.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the characters which are available in a font and their codes.

The currently defined constants of CharSet have the same numerical values as the corresponding enum values of the C/C++ rtl_TextEncoding (from rtl/textenc.h). This correspondence is by design. Since CharSet is deprecated, however, it is not planned to add further constants to keep it in sync with rtl_TextEncoding.

.. deprecated::

    Class is deprecated.

See Also:
    `API CharSet <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1CharSet.html>`_
"""
DONTKNOW: Literal[0]
"""
specifies an unknown character set.
"""
ANSI: Literal[1]
"""
specifies the ANSI character set.
"""
MAC: Literal[2]
"""
specifies the Apple Macintosh character set.
"""
IBMPC_437: Literal[3]
"""
specifies the IBM PC character set number 437.
"""
IBMPC_850: Literal[4]
"""
specifies the IBM PC character set number 850.
"""
IBMPC_860: Literal[5]
"""
specifies the IBM PC character set number 860.
"""
IBMPC_861: Literal[6]
"""
specifies the IBM PC character set number 861.
"""
IBMPC_863: Literal[7]
"""
specifies the IBM PC character set number 863.
"""
IBMPC_865: Literal[8]
"""
specifies the IBM PC character set number 865.
"""
SYSTEM: Literal[9]
"""
specifies the system character set.
"""
SYMBOL: Literal[10]
"""
specifies a set of symbols.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.uno
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API TypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328>`_
"""

ANY: 'uno.Enum'
"""
reflecting the any type; anys can carry any UNO value except of any values
"""
ARRAY: 'uno.Enum'
"""
Deprecated, UNOIDL does not have an array concept.
"""
BOOLEAN: 'uno.Enum'
"""
reflecting the boolean type; true and false
"""
BYTE: 'uno.Enum'
"""
reflecting the 8-bit ordinal type
"""
CHAR: 'uno.Enum'
"""
reflecting the 16-bit unicode character type
"""
CONSTANT: 'uno.Enum'
"""
reflecting constants
"""
CONSTANTS: 'uno.Enum'
"""
reflecting constants groups
"""
DOUBLE: 'uno.Enum'
"""
reflecting the 64-bit floating point type
"""
ENUM: 'uno.Enum'
"""
reflecting enum types
"""
EXCEPTION: 'uno.Enum'
"""
reflecting exception types
"""
FLOAT: 'uno.Enum'
"""
reflecting the 32-bit floating point type
"""
HYPER: 'uno.Enum'
"""
reflecting the signed 64-bit ordinal type
"""
INTERFACE: 'uno.Enum'
"""
reflecting interface types
"""
INTERFACE_ATTRIBUTE: 'uno.Enum'
"""
reflecting interface attributes
"""
INTERFACE_METHOD: 'uno.Enum'
"""
reflecting interface methods
"""
LONG: 'uno.Enum'
"""
reflecting the signed 32-bit ordinal type
"""
MODULE: 'uno.Enum'
"""
reflecting modules
"""
PROPERTY: 'uno.Enum'
"""
reflecting properties
"""
SEQUENCE: 'uno.Enum'
"""
reflecting sequence types
"""
SERVICE: 'uno.Enum'
"""
reflecting services
"""
SHORT: 'uno.Enum'
"""
reflecting the signed 16-bit ordinal type
"""
SINGLETON: 'uno.Enum'
"""
reflecting singletons
"""
STRING: 'uno.Enum'
"""
reflecting the string type; strings of unicode characters
"""
STRUCT: 'uno.Enum'
"""
reflecting compound types
"""
TYPE: 'uno.Enum'
"""
reflecting the meta type
"""
TYPEDEF: 'uno.Enum'
"""
reflecting typedefed types referencing other types
"""
UNION: 'uno.Enum'
"""
Deprecated, UNOIDL does not have a union concept.
"""
UNKNOWN: 'uno.Enum'
"""
reflecting the unreflectable type
"""
UNSIGNED_HYPER: 'uno.Enum'
"""
reflecting the unsigned 64-bit ordinal type
"""
UNSIGNED_LONG: 'uno.Enum'
"""
reflecting the unsigned 32-bit type
"""
UNSIGNED_SHORT: 'uno.Enum'
"""
reflecting the unsigned 16-bit ordinal type
"""
VOID: 'uno.Enum'
"""
reflecting the void type; denotes no type
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from .x_dispatch_information_provider import XDispatchInformationProvider as XDispatchInformationProvider_afb6126c
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from .x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception_c2a512da
from .x_frames_supplier import XFramesSupplier as XFramesSupplier_e12a0d1d
from ..task.x_status_indicator_factory import XStatusIndicatorFactory as XStatusIndicatorFactory_49e4100c
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from .x_dispatch_recorder_supplier import XDispatchRecorderSupplier as XDispatchRecorderSupplier_79301125
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XFrame2(XDispatchInformationProvider_afb6126c, XDispatchProvider_fc690de6, XDispatchProviderInterception_c2a512da, XFramesSupplier_e12a0d1d, XStatusIndicatorFactory_49e4100c):
    """
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XFrame2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XFrame2']

    @property
    def DispatchRecorderSupplier(self) -> 'XDispatchRecorderSupplier_79301125':
        """
        provides access to the dispatch recorder of the frame
        
        Such recorder can be used to record dispatch requests. The supplier contains a dispatch recorder and provide the functionality to use it for any dispatch object from outside which supports the interface XDispatch. A supplier is available only, if recording was enabled. That means: if someone wishes to enable recoding on a frame he must set a supplier with a recorder object inside of it. Every user of dispatches has to check then if such supplier is available at this frame property. If value of this property is NULL he must call XDispatch.dispatch() on the original dispatch object. If it's a valid value he must use the supplier by calling his method XDispatchRecorderSupplier.dispatchAndRecord() with the original dispatch object as argument.
        
        Note:
        It's not recommended to cache an already gotten supplier. Because there exist no possibility to check for enabled/disabled recording then.
        
        **since**
        
            OOo 1.1.2
        """

    @property
    def LayoutManager(self) -> 'XInterface_8f010a43':
        """
        Provides access to the LayoutManager of the frame.
        
        This is actually of type XLayoutManager, but this API is still experimental (unpublished).
        """

    @property
    def Title(self) -> str:
        """
        if possible it sets/gets the UI title on/from the frame container window
        
        It depends from the type of the frame container window. If it is a system task window all will be OK. Otherwise the title can't be set. Setting/getting of the pure value of this property must be possible in every case. Only showing on the UI can be fail.
        """

    @property
    def UserDefinedAttributes(self) -> 'XNameContainer_cb90e47':
        """
        contains user defined attributes.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.tree
from typing_extensions import Literal
import typing
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .tree_expansion_event import TreeExpansionEvent as TreeExpansionEvent_378b0f79

class XTreeExpansionListener(XEventListener_c7230c4a):
    """
    An instance of this interface can get notifications from a TreeControl when nodes are expanded or collapsed.

    See Also:
        `API XTreeExpansionListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.tree.XTreeExpansionListener']

    def requestChildNodes(self, Event: 'TreeExpansionEvent_378b0f79') -> None:
        """
        Invoked when a node with children on demand is about to be expanded.
        
        This event is invoked before the treeExpanding() event.
        """
    def treeCollapsed(self, Event: 'TreeExpansionEvent_378b0f79') -> None:
        """
        Called whenever a node in the tree has been successfully collapsed.
        """
    def treeCollapsing(self, Event: 'TreeExpansionEvent_378b0f79') -> None:
        """
        Invoked whenever a node in the tree is about to be collapsed.

        Raises:
            ExpandVetoException: ``ExpandVetoException``
        """
    def treeExpanded(self, Event: 'TreeExpansionEvent_378b0f79') -> None:
        """
        Called whenever a node in the tree has been successfully expanded.
        """
    def treeExpanding(self, Event: 'TreeExpansionEvent_378b0f79') -> None:
        """
        Invoked whenever a node in the tree is about to be expanded.

        Raises:
            ExpandVetoException: ``ExpandVetoException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .file_picker_event import FilePickerEvent as FilePickerEvent_25670ed7

class XFilePickerListener(XEventListener_c7230c4a):
    """
    Interface to be implemented by a FilePicker listener.
    
    The XFilePickerListener interface must be implemented by the clients of the FilePicker service which need to be informed about events while the FilePicker service is displayed.

    See Also:
        `API XFilePickerListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePickerListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XFilePickerListener']

    def controlStateChanged(self, aEvent: 'FilePickerEvent_25670ed7') -> None:
        """
        A client receives this event if the state of a control within the FilePicker service dialog changes.
        """
    def dialogSizeChanged(self) -> None:
        """
        A client receives this event if the size of the FilePicker dialog has changed.
        
        If the FilePicker dialog contains a preview the client may ask for the new dimension of the preview area.
        """
    def directoryChanged(self, aEvent: 'FilePickerEvent_25670ed7') -> None:
        """
        A client receives this event if the directory selection within the FilePicker dialog changes.
        """
    def fileSelectionChanged(self, aEvent: 'FilePickerEvent_25670ed7') -> None:
        """
        A client receives this event if the file selection within the FilePicker service dialog changes.
        """
    def helpRequested(self, aEvent: 'FilePickerEvent_25670ed7') -> str:
        """
        A client receives this event if the F1 key or the help button was pressed.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.scanner
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class ScanError(Enum):
    """
    Enum

    

    See Also:
        `API ScanError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1scanner.html#abd1619ea132004db8599d9529755e9ab>`_
    """

    InvalidContext: 'uno.Enum'
    """
    InvalidContext: a device was requested that does not exist.
    """
    ScanCanceled: 'uno.Enum'
    """
    ScanCanceled: the scan was canceled by the user.
    """
    ScanErrorNone: 'uno.Enum'
    """
    ScanErrorNone: no error occurred.
    """
    ScanFailed: 'uno.Enum'
    """
    ScanFailed: an error occurred during scanning.
    """
    ScanInProgress: 'uno.Enum'
    """
    ScanInProgress: a scan is already in progress on this device that has to end before a new one can be started.
    """
    ScannerNotAvailable: 'uno.Enum'
    """
    ScannerNotAvailable: the requested device could not be opened.
    """

